# Table of Contents

- [ai-capabilities](<./ai-capabilities.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [AI Capabilities](<./AI-Capabilities.md>)
  - [Overview](<./AI-Capabilities/Overview.md>)
  - [Benefits](<./AI-Capabilities/Benefits.md>)
  - [Transparency and Governance of AI Features](<./AI-Capabilities/Transparency-and-Governance-of-AI-Features.md>)
  - [Base AI Capabilities](<./AI-Capabilities/Base-AI-Capabilities.md>)
  - [Inventory Builder](<./AI-Capabilities/Inventory-Builder.md>)
  - [Joule in SAP LeanIX](<./AI-Capabilities/Joule-in-SAP-LeanIX.md>)
  - [Prerequisites](<./AI-Capabilities/Prerequisites.md>)
  - [Activating AI Capabilities](<./AI-Capabilities/Activating-AI-Capabilities.md>)
  - [Deactivating AI Capabilities](<./AI-Capabilities/Deactivating-AI-Capabilities.md>)
  - [Frequently Asked Questions](<./AI-Capabilities/Frequently-Asked-Questions.md>)
